You can read more about how to find older records in [the civil court cases : Kings/Queens bench division research guide](https://www.nationalarchives.gov.uk/help-with-your-research/research-guides/court-of-kings-bench-plea-side-and-kings-queens-bench-division-cases-1702-1998/){target="\_blank"}.
